@@ -14,6 +14,15 @@ import (
 // MD5 encodes string to MD5.
 type MD5 struct{}
 
+// Implement ConfigurableStreamingProcessor interface for optimized streaming
+func (p MD5) GetStreamingConfig() StreamingConfig {
+	return StreamingConfig{
+		ChunkSize:    64 * 1024, // 64KB chunks
+		BufferOutput: true,      // Hash functions need full input
+		LineByLine:   false,
+	}
+}
+
 func (p MD5) Name() string {
 	return "md5"
 }
@@ -49,6 +58,15 @@ func (p MD5) FilterValue() string {
 // SHA1 encodes string to SHA-1.
 type SHA1 struct{}
 
+// Implement ConfigurableStreamingProcessor interface for optimized streaming
+func (p SHA1) GetStreamingConfig() StreamingConfig {
+	return StreamingConfig{
+		ChunkSize:    64 * 1024, // 64KB chunks
+		BufferOutput: true,      // Hash functions need full input
+		LineByLine:   false,
+	}
+}
+
 func (p SHA1) Name() string {
 	return "sha1"
 }
@@ -85,6 +103,15 @@ func (p SHA1) FilterValue() string {
 // SHA256 encodes string to SHA-256.
 type SHA256 struct{}
 
+// Implement ConfigurableStreamingProcessor interface for optimized streaming
+func (p SHA256) GetStreamingConfig() StreamingConfig {
+	return StreamingConfig{
+		ChunkSize:    64 * 1024, // 64KB chunks
+		BufferOutput: true,      // Hash functions need full input
+		LineByLine:   false,
+	}
+}
+
 func (p SHA256) Name() string {
 	return "sha256"
 }
@@ -121,6 +148,15 @@ func (p SHA256) FilterValue() string {
 // SHA512 encodes string to SHA-512.
 type SHA512 struct{}
 
+// Implement ConfigurableStreamingProcessor interface for optimized streaming
+func (p SHA512) GetStreamingConfig() StreamingConfig {
+	return StreamingConfig{
+		ChunkSize:    64 * 1024, // 64KB chunks
+		BufferOutput: true,      // Hash functions need full input
+		LineByLine:   false,
+	}
+}
+
 func (p SHA512) Name() string {
 	return "sha512"
 }
@@ -157,6 +193,15 @@ func (p SHA512) FilterValue() string {
 // SHA224 encode string to SHA-224.
 type SHA224 struct{}
 
+// Implement ConfigurableStreamingProcessor interface for optimized streaming
+func (p SHA224) GetStreamingConfig() StreamingConfig {
+	return StreamingConfig{
+		ChunkSize:    64 * 1024, // 64KB chunks
+		BufferOutput: true,      // Hash functions need full input
+		LineByLine:   false,
+	}
+}
+
 func (p SHA224) Name() string {
 	return "sha224"
 }
@@ -191,6 +236,15 @@ func (p SHA224) FilterValue() string {
 // SHA384 encodes string to SHA-384.
 type SHA384 struct{}
 
+// Implement ConfigurableStreamingProcessor interface for optimized streaming
+func (p SHA384) GetStreamingConfig() StreamingConfig {
+	return StreamingConfig{
+		ChunkSize:    64 * 1024, // 64KB chunks
+		BufferOutput: true,      // Hash functions need full input
+		LineByLine:   false,
+	}
+}
+
 func (p SHA384) Name() string {
 	return "sha384"
 }
