@@ -6,6 +6,8 @@ import (
 	"strings"
 
 	"github.com/abhimanyu003/sttr/utils"
+	"golang.org/x/text/cases"
+	"golang.org/x/text/language"
 
 	"github.com/iancoleman/strcase"
 )
@@ -14,6 +16,15 @@ import (
 // Example: "THIS IS STRING" to "this is string".
 type Lower struct{}
 
+// Implement ConfigurableStreamingProcessor interface for chunked processing
+func (p Lower) GetStreamingConfig() StreamingConfig {
+	return StreamingConfig{
+		ChunkSize:    64 * 1024, // 64KB chunks
+		BufferOutput: false,     // Can process chunks directly
+		LineByLine:   false,
+	}
+}
+
 func (p Lower) Name() string {
 	return "lower"
 }
@@ -47,6 +58,15 @@ func (p Lower) FilterValue() string {
 // Example: "this is string" to "THIS IS STRING".
 type Upper struct{}
 
+// Implement ConfigurableStreamingProcessor interface for chunked processing
+func (p Upper) GetStreamingConfig() StreamingConfig {
+	return StreamingConfig{
+		ChunkSize:    64 * 1024, // 64KB chunks
+		BufferOutput: false,     // Can process chunks directly
+		LineByLine:   false,
+	}
+}
+
 func (p Upper) Name() string {
 	return "upper"
 }
@@ -89,7 +109,7 @@ func (p Title) Alias() []string {
 }
 
 func (p Title) Transform(data []byte, _ ...Flag) (string, error) {
-	return strings.Title(string(data)), nil
+	return cases.Title(language.Und, cases.NoLower).String(string(data)), nil
 }
 
 func (p Title) Flags() []Flag {
@@ -281,6 +301,15 @@ func (p Slug) FilterValue() string {
 // CountCharacters count number of characters including spaces.
 type CountCharacters struct{}
 
+// Implement ConfigurableStreamingProcessor interface for character counting
+func (p CountCharacters) GetStreamingConfig() StreamingConfig {
+	return StreamingConfig{
+		ChunkSize:    64 * 1024, // 64KB chunks
+		BufferOutput: true,      // Need full input to count characters accurately
+		LineByLine:   false,
+	}
+}
+
 func (p CountCharacters) Name() string {
 	return "count-chars"
 }
@@ -314,6 +343,15 @@ func (p CountCharacters) FilterValue() string {
 // Example: "hello world" = 2.
 type CountWords struct{}
 
+// Implement ConfigurableStreamingProcessor interface for word counting
+func (p CountWords) GetStreamingConfig() StreamingConfig {
+	return StreamingConfig{
+		ChunkSize:    64 * 1024, // 64KB chunks
+		BufferOutput: true,      // Need full input to count words accurately
+		LineByLine:   false,
+	}
+}
+
 func (p CountWords) Name() string {
 	return "count-words"
 }
@@ -393,31 +431,31 @@ func (p EscapeQuotes) Alias() []string {
 }
 
 func (p EscapeQuotes) Transform(data []byte, f ...Flag) (string, error) {
-	result := ""
+	var result strings.Builder
 	for _, v := range data {
 		for _, flag := range f {
 			switch flag.Short {
 			case "d":
 				if v == '"' {
-					result += "\\"
+					result.WriteString("\\")
 				}
 			case "s":
 				if v == '\'' {
-					result += "\\"
+					result.WriteString("\\")
 				}
 			}
 		}
 		if len(f) == 0 {
 			if v == '"' {
-				result += "\\"
+				result.WriteString("\\")
 			}
 			if v == '\'' {
-				result += "\\"
+				result.WriteString("\\")
 			}
 		}
-		result += string(v)
+		result.WriteString(string(v))
 	}
-	return result, nil
+	return result.String(), nil
 }
 
 func (p EscapeQuotes) Flags() []Flag {
